Summary:        Java command line parser with both an annotations API and a programmatic API
Name:           picocli
Version:        4.6.3
Release:        3%{?dist}
License:        ASL 2.0
URL:            https://github.com/remkop/picocli
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/info/picocli/%{name}/%{version}/%{name}-%{version}.pom
Source2:        https://repo1.maven.org/maven2/info/picocli/%{name}-codegen/%{version}/%{name}-codegen-%{version}.pom
Source3:        https://repo1.maven.org/maven2/info/picocli/%{name}-shell-jline3/%{version}/%{name}-shell-jline3-%{version}.pom

BuildArch:      noarch
ExclusiveArch:  %{java_arches} noarch

BuildRequires: mvn(org.jline:jline-console) mvn(org.jline:jline-reader) mvn(org.jline:jline-terminal-jansi)
BuildRequires: maven-local mvn(org.codehaus.mojo:build-helper-maven-plugin) mvn(org.jline:jline-builtins)

%description
Picocli is a modern library and framework, written in Java, that contains both
an annotations API and a programmatic API. It features usage help with ANSI
colors and styles, TAB auto-completion and nested sub-commands. In a single
file, so you can include it in source form. This lets users run picocli-based
applications without requiring picocli as an external dependency.

%package -n %{name}-codegen
Summary:        Tools to generate documentation, configuration, source code from a picocli model

%description -n %{name}-codegen
The picocli-codegen (Picocli Code Generation) module contains tools for
generating configuration files and documentation for picocli-based applications.

%package -n %{name}-shell-jline3
Summary:        Easily build interactive shell applications with JLine 3 and picocli

%description -n %{name}-shell-jline3
Picocli Shell JLine3 contains components and documentation for building
interactive shell command line applications with JLine 3 and picocli.

%prep
%autosetup

find -type f '(' -iname '*.jar' -o -iname '*.class' ')' -print -delete

mkdir %{name}

mv src/ %{name}

cp -p %{SOURCE1} %{name}/pom.xml

cp -p %{SOURCE2} %{name}-codegen/pom.xml

cp -p %{SOURCE3} %{name}-shell-jline3/pom.xml

cp -p %{SOURCE1} pom.xml

%pom_xpath_set pom:artifactId %{name}-parent
%pom_xpath_set pom:name %{name}-parent
%pom_xpath_inject pom:project '<packaging>pom</packaging>'

%pom_xpath_inject pom:project '
  <modules>
    <module>%{name}</module>
    <module>%{name}-tests</module>
    <module>%{name}-codegen</module>
    <module>%{name}-shell-jline3</module>
  </modules>'

%pom_xpath_set pom:name %{name} %{name}

%pom_remove_dep org.jline:jline %{name}-shell-jline3
%pom_add_dep org.jline:jline-builtins %{name}-shell-jline3
%pom_add_dep org.jline:jline-console %{name}-shell-jline3
%pom_add_dep org.jline:jline-reader %{name}-shell-jline3
%pom_add_dep org.jline:jline-terminal-jansi %{name}-shell-jline3

%pom_add_plugin org.codehaus.mojo:build-helper-maven-plugin:3.2.0 %{name} '
  <executions>
    <execution>
      <id>add-source</id>
      <phase>generate-sources</phase>
      <goals>
        <goal>add-source</goal>
      </goals>
      <configuration>
        <sources>
          <source>src/main/java9</source>
        </sources>
      </configuration>
    </execution>
  </executions>'

%pom_add_plugin :maven-compiler-plugin:3.8.1 %{name} '
  <configuration>
      <release>9</release>
  </configuration>
  <executions>
      <execution>
          <id>base-compile</id>
          <goals>
              <goal>compile</goal>
          </goals>
          <configuration>
              <release>8</release>
              <excludes>
                  <exclude>module-info.java</exclude>
              </excludes>
          </configuration>
      </execution>
  </executions>'

%pom_add_plugin :maven-compiler-plugin:3.8.1 %{name}-codegen '
  <configuration>
    <proc>none</proc>
  </configuration>'

%pom_add_plugin :maven-jar-plugin:3.2.0 %{name} '
  <configuration>
    <archive>
      <manifestEntries>
        <Specification-Title>picocli</Specification-Title>
        <Specification-Version>${project.version}</Specification-Version>
        <Specification-Vendor>Remko Popma</Specification-Vendor>
        <Implementation-Title>picocli</Implementation-Title>
        <Implementation-Version>${project.version}</Implementation-Version>
        <Implementation-Vendor>Remko Popma</Implementation-Vendor>
        <Main-Class>picocli.AutoComplete</Main-Class>
        <Multi-Release>true</Multi-Release>
      </manifestEntries>
    </archive>
  </configuration>'

%pom_add_plugin :maven-jar-plugin:3.2.0 %{name}-codegen '
  <configuration>
    <archive>
      <manifestEntries>
        <Specification-Title>Picocli Code Generation</Specification-Title>
        <Specification-Version>${project.version}</Specification-Version>
        <Specification-Vendor>Remko Popma</Specification-Vendor>
        <Implementation-Title>Picocli Code Generation</Implementation-Title>
        <Implementation-Version>${project.version}</Implementation-Version>
        <Implementation-Vendor>Remko Popma</Implementation-Vendor>
        <Automatic-Module-Name>info.picocli.codegen</Automatic-Module-Name>
      </manifestEntries>
    </archive>
  </configuration>'

%pom_add_plugin :maven-jar-plugin:3.2.0 %{name}-shell-jline3 '
  <configuration>
    <archive>
      <manifestEntries>
        <Specification-Title>Picocli Shell JLine3</Specification-Title>
        <Specification-Version>${project.version}</Specification-Version>
        <Specification-Vendor>Remko Popma</Specification-Vendor>
        <Implementation-Title>Picocli Shell JLine3</Implementation-Title>
        <Implementation-Version>${project.version}</Implementation-Version>
        <Implementation-Vendor>Remko Popma</Implementation-Vendor>
        <Automatic-Module-Name>info.picocli.shell.jline3</Automatic-Module-Name>
      </manifestEntries>
    </archive>
  </configuration>'

mkdir -p %{name}-tests/src/main/java/picocli
mv %{name}/src/test/java/picocli/{Demo.java,CustomLayoutDemo.java,Size.java,WindowsJansiDemo.java} %{name}-tests/src/main/java/picocli
cp -p %{SOURCE1} %{name}-tests/pom.xml
%pom_xpath_set pom:artifactId %{name}-tests %{name}-tests
%pom_xpath_set pom:name %{name}-tests %{name}-tests
%pom_add_dep info.picocli:picocli:%{version}:compile %{name}-tests
%pom_add_dep org.fusesource.jansi:jansi %{name}-tests

%mvn_package :%{name}-parent __noinstall

%build
%mvn_build -s -f -j -- -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%files -n %{name} -f .mfiles-%{name}
%{_datadir}/maven-metadata/picocli-picocli-tests.xml
%{_javadir}/picocli/picocli-tests.jar
%{_mavenpomdir}/picocli/picocli-tests.pom
%license LICENSE
%doc README.md RELEASE-NOTES.md

%files -n %{name}-codegen -f .mfiles-%{name}-codegen
%license LICENSE
%doc %{name}-codegen/README.adoc

%files -n %{name}-shell-jline3 -f .mfiles-%{name}-shell-jline3
%license LICENSE
%doc %{name}-shell-jline3/README.md

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.6.3-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.6.3-2
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 25 2023 cunshunxia <cunshunxia@tencent.com> - 4.6.3-1
- initial build
